@@ -60,7 +60,10 @@
       inputTS <- fread(path, integer64 = "numeric", header = FALSE, select = colSelect)
     }
     
-    inputTS<-.reorderInputTSHydroStorage(inputTS, path, opts)
+    if (opts$antaresVersion < 650) {
+      inputTS <- .reorderInputTSHydroStorage(inputTS, path, opts)
+    }
+    
     inputTS <- inputTS[timeRange[1]:timeRange[2]]
   }
   
@@ -114,14 +117,20 @@
 }
 
 .importHydroStorageInput <- function(area, timeStep, opts, ...) {
+  inputTimeStepV <- ifelse(opts$antaresVersion >= 650, yes = "hourly", no = "monthly")
   .importInputTS(area, timeStep, opts, "hydro/series/%s/mod.txt", "hydroStorage", 
-                 inputTimeStep = "monthly", type = "matrix")
+                 inputTimeStep = inputTimeStepV, type = "matrix")
 }
   
 .importHydroStorageMaxPower <- function(area, timeStep, opts, unselect = NULL, ...) {
   
-  beginName <- c("hstorPMaxLow", "hstorPMaxAvg", "hstorPMaxHigh")
   unselect = unselect$areas
+  if (opts$antaresVersion >= 650) {
+    beginName <- c("generatingMaxPower", "generatingMaxEnergy", 
+                   "pumpingMaxPower", "pumpingMaxEnergy")
+  } else {
+    beginName <- c("hstorPMaxLow", "hstorPMaxAvg", "hstorPMaxHigh")
+  }
   
   if(!is.null(unselect)){
     colSelect <- which(!beginName%in%unselect)
@@ -191,8 +200,18 @@
   areas <- strsplit(link, " - ")[[1]]
   
   unselect <- unselect$links
-  beginName <- c("transCapacityDirect", "transCapacityIndirect",
-                 "impedances", "hurdlesCostDirect", "hurdlesCostIndirect")
+  
+  #TODO DEL after some antaresVersion, by example, del this check after Antares
+  #version 8 and check in readAntares the version
+  if (opts$antaresVersion >= 650) {
+    beginName <- c("transCapacityDirect", "transCapacityIndirect",
+                   "hurdlesCostDirect", "hurdlesCostIndirect",
+                   "impedances", "loopFlow", "p.ShiftMin", "p.ShiftMax")    
+  } else {
+    beginName <- c("transCapacityDirect", "transCapacityIndirect",
+                   "impedances", "hurdlesCostDirect", "hurdlesCostIndirect")
+  }
+  
   if(!is.null(unselect)){
     colSelect <- which(!beginName%in%unselect)
     names <- beginName[colSelect]
