@@ -2,7 +2,13 @@
 
 # Copy the test study in a temporary folder
 
-path <- tempdir()
+path0 <- tempdir()
+dir.create(file.path(path0, "v6"))
+dir.create(file.path(path0, "v7"))
+
+path <- file.path(path0, "v6")
+pathv7 <- file.path(path0, "v7")
+
 sourcedir <- system.file("inst/testdata", package = "antaresRead")
 testH5 <- TRUE
 if(sourcedir == ""){ sourcedir <- system.file("testdata", package = "antaresRead")}
@@ -20,12 +26,8 @@ if (length(strsplit(packageDescription("antaresRead")$Version, "\\.")[[1]]) > 3)
 # the R CMD CHECK before package is correctly installed and tests actually run. 
 # The following "if" prevents errors at this step
 if (sourcedir != "") {
-  # if (Sys.info()['sysname'] == "Windows") {
-  #   untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path, 
-  #         extras = "--force-local")
-  # } else {
-    untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path)
-  # }
+  untar(file.path(sourcedir, "antares-test-study.tar.gz"), exdir = path)
+  untar(file.path(sourcedir, "antares-test-study-v7.tar.gz"), exdir = pathv7)
   
   if(.requireRhdf5_Antares(stopP = FALSE) & .runH5Test){
     
@@ -48,7 +50,7 @@ if (sourcedir != "") {
     })
     
     #if you change the tar file then you must also change this file
-    h5file <- "20180423-1734eco-test.h5"
+    h5file <- "20190321-2217eco-test.h5"
     
     deprintize<-function(f){
       return(function(...) {capture.output(w<-f(...));return(w);});
@@ -105,7 +107,9 @@ if (sourcedir != "") {
     assign("studyPathS", c(file.path(path), file.path(path, "test_case")), envir = globalenv())
     
   } else {
-    assign("studyPathS", file.path(path, "test_case"), envir = globalenv())
+    assign("studyPathS", 
+           c(file.path(path, "test_case"), file.path(pathv7, "test_case")),
+           envir = globalenv())
   }
   
   assign("nweeks", 2, envir = globalenv())
